# Disk

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**create_time** | **datetime** |  | [optional] 
**data_center_id** | **str** |  | [optional] 
**disk_state** | [**DiskState**](DiskState.md) |  | [optional] 
**disk_type** | [**DiskType**](DiskType.md) |  | [optional] 
**id** | **str** |  | [optional] 
**private_image_id** | **str** |  | [optional] 
**project_id** | **str** |  | [optional] 
**public_image_id** | **str** |  | [optional] 
**size_gib** | **int** |  | 
**storage_class** | [**DiskStorageClass**](DiskStorageClass.md) |  | [optional] 
**vm_id** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


